{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "Filter Protein Alignments",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.uniColl_asn_cache)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "align_filter",
            "arguments": [
                "-filter",
                "pct_identity_gapopen_only >= 50 AND ( (query_start<=20 AND SUB(query_length, query_end)<=20) OR pct_identity_gapopen_only >= 60 ) AND (SUB(subject_end, subject_start) > 90 || SUB(subject_end, subject_start) > MUL(query_length,1.5) || num_ident >=60) AND (query_length > 30 || (pct_identity_gapopen_only >= 80 AND SUB(subject_end, subject_start) >= MUL(query_length,2.4)))",
                "-ifmt",
                "seq-align",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache",
                        "valueFrom": "$(inputs.asn_cache.basename),$(inputs.uniColl_asn_cache.basename)"
                    },
                    "id": "#align_filter.cwl/asn_cache"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input"
                    },
                    "id": "#align_filter.cwl/file_in"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "align.asn",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#align_filter.cwl/output"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "align-nomatch.asn",
                    "inputBinding": {
                        "prefix": "-non-match-output"
                    },
                    "id": "#align_filter.cwl/output_non_match"
                },
                {
                    "type": "Directory",
                    "id": "#align_filter.cwl/uniColl_asn_cache"
                }
            ],
            "id": "#align_filter.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#align_filter.cwl/align"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_non_match)"
                    },
                    "id": "#align_filter.cwl/align_non_match"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "file concatenation",
            "baseCommand": "cat",
            "stdout": "out.asn",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cat.cwl/file_in_1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#cat.cwl/file_in_2"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cat.cwl/file_out",
                    "outputBinding": {
                        "glob": "out.asn"
                    }
                }
            ],
            "id": "#cat.cwl"
        },
        {
            "class": "Workflow",
            "label": "Filter Protein Alignments",
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#main/asn_cache"
                },
                {
                    "type": "File",
                    "id": "#main/blast_full"
                },
                {
                    "type": "File",
                    "id": "#main/prosplign"
                },
                {
                    "type": "Directory",
                    "id": "#main/uniColl_asn_cache"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/align_filter/align",
                    "id": "#main/align"
                },
                {
                    "type": "File",
                    "outputSource": "#main/align_filter/align_non_match",
                    "id": "#main/align_non_match"
                }
            ],
            "steps": [
                {
                    "run": "#align_filter.cwl",
                    "in": [
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/align_filter/asn_cache"
                        },
                        {
                            "source": "#main/cat/file_out",
                            "id": "#main/align_filter/file_in"
                        },
                        {
                            "source": "#main/uniColl_asn_cache",
                            "id": "#main/align_filter/uniColl_asn_cache"
                        }
                    ],
                    "out": [
                        "#main/align_filter/align",
                        "#main/align_filter/align_non_match"
                    ],
                    "id": "#main/align_filter"
                },
                {
                    "run": "#cat.cwl",
                    "in": [
                        {
                            "source": "#main/blast_full",
                            "id": "#main/cat/file_in_1"
                        },
                        {
                            "source": "#main/prosplign",
                            "id": "#main/cat/file_in_2"
                        }
                    ],
                    "out": [
                        "#main/cat/file_out"
                    ],
                    "id": "#main/cat"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.2"
}
